@@ -142,24 +142,26 @@ test_that("fit dburrIII2 cis", {
   set.seed(77)
   hc <- ssd_hc(dist, ci = TRUE, nboot = 10)
   expect_is(hc, "tbl_df")
-  expect_identical(colnames(hc), c("percent", "est", "se", "lcl", "ucl", "dist"))
+  expect_identical(colnames(hc), c("percent", "est", "se", "lcl", "ucl", "dist", "wt"))
   expect_identical(hc$percent, 5)
   expect_equal(hc$est, 1.56256632555312)
   expect_equal(hc$se, 0.533080817076427)
   expect_equal(hc$lcl, 1.02028787432084)
   expect_equal(hc$ucl, 2.4100026087857)
   expect_equal(hc$dist, "burrIII2")
+  expect_equal(hc$wt, 1)
   
   set.seed(77)
   hp <- ssd_hp(dist, conc = 2, ci = TRUE, nboot = 10)
   expect_is(hp, "tbl_df")
-  expect_identical(colnames(hp), c("conc", "est", "se", "lcl", "ucl", "dist"))
+  expect_identical(colnames(hp), c("conc", "est", "se", "lcl", "ucl", "dist", "wt"))
   expect_equal(hp$conc, 2)
   expect_equal(hp$est, 6.8431214411277)
   expect_equal(hp$se, 2.53471375726922)
   expect_equal(hp$lcl, 3.73102816675466)
   expect_equal(hp$ucl, 10.3929969316288)
   expect_equal(hp$dist, "burrIII2")
+  expect_equal(hp$wt, 1)
 })
 
 test_that("burrIII2 and llogis identical", {
