@@ -140,24 +140,26 @@ test_that("fit gompertz cis", {
 
   hc <- ssd_hc(dist, ci = TRUE, nboot = 10)
   expect_is(hc, "tbl_df")
-  expect_identical(colnames(hc), c("percent", "est", "se", "lcl", "ucl", "dist"))
+  expect_identical(colnames(hc), c("percent", "est", "se", "lcl", "ucl", "dist", "wt"))
   expect_identical(hc$percent, 5)
   expect_equal(hc$est, 1.29947858260222)
   expect_equal(hc$se, 0.234474369346749)
   expect_equal(hc$lcl, 0.966156147429702)
   expect_equal(hc$ucl, 1.58273480439059)
   expect_equal(hc$dist, "gompertz")
+  expect_equal(hc$wt, 1)
   expect_error(stringsAsFactors = TRUE)
 
   set.seed(77)
   hp <- ssd_hp(dist, conc = 2, ci = TRUE, nboot = 10)
   expect_is(hp, "tbl_df")
-  expect_identical(colnames(hp), c("conc", "est", "se", "lcl", "ucl", "dist"))
+  expect_identical(colnames(hp), c("conc", "est", "se", "lcl", "ucl", "dist", "wt"))
   expect_identical(hp$conc, 2)
   expect_equal(hp$est, 7.59650778517608, tolerance = 1e-2)
   expect_equal(hp$se, 1.14891770368466, tolerance = 1e-2) 
   expect_equal(hp$lcl, 6.0020990844966, tolerance = 1e-2)
   expect_equal(hp$ucl, 9.22516202386345, tolerance = 1e-2)
   expect_equal(hp$dist, "gompertz")
+  expect_equal(hp$wt, 1)
   expect_error(stringsAsFactors = TRUE)
 })
